@@ -1,23 +1,5 @@
 package SQL::Translator::Producer::Latex;
 
-# -------------------------------------------------------------------
-# Copyright (C) 2002-2009 SQLFairy Authors
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-# 02111-1307  USA
-# -------------------------------------------------------------------
-
 =pod
 
 =head1 NAME
@@ -52,13 +34,11 @@ automatically arrange them horizontally or vertically.
 
 =cut
 
-# -------------------------------------------------------------------
-
 use strict;
+use warnings;
 
-use vars qw[ $DEBUG $VERSION @EXPORT_OK ];
-$VERSION = '1.60';
-$DEBUG   = 0 unless defined $DEBUG;
+our @EXPORT_OK;
+our $VERSION = '1.59';
 
 use SQL::Translator::Utils 'debug';
 
@@ -103,16 +83,14 @@ sub latex {
     $s =~ s/([\&\_\$\{\#])/\\$1/g;
     return $s;
 }
- 
-1;
 
-# -------------------------------------------------------------------
+1;
 
 =pod
 
 =head1 AUTHOR
 
-Chris Mungall.
+Chris Mungall
 
 =head1 SEE ALSO
 
